@@ -13,6 +13,7 @@ class Console:
     width: int
     height: int
     font: pygame.font.Font
+    font_path: str
     text_width: int
     text_height: int
     window_width: int
@@ -56,7 +57,11 @@ class Console:
         self.height = height
         self.height_offset = 0
         pygame.init()
-        self.font = pygame.font.Font(os.path.dirname(os.path.abspath(__file__)) + r'\Apple Hei.ttf', font_height)
+        self.font_path = os.path.dirname(os.path.abspath(__file__)) + r'\Apple Hei.ttf'
+        if not os.path.exists(self.font_path):
+            from .Apple_Hei_packed import unpack
+            unpack(self.font_path)
+        self.font = pygame.font.Font(self.font_path, font_height)
         [self.text_width, self.text_height] = self.font.size('a')
         self.text_height -= self.height_offset * 2
         [self.window_width, self.window_height] = [self.width * self.text_width,
@@ -145,7 +150,7 @@ class Console:
 
             if now - self.fps_last_update_time >= 1000:
                 print('fps:', self.fps_cnt * 1000 / (now - self.fps_last_update_time))
-                self.fps_cnt = 0
+                self.fps_cnt = 1
                 self.fps_last_update_time = now
 
             for event in pygame.event.get():
